aboutsummaryrefslogtreecommitdiff
path: root/gdb/tm-sun4sol2.h
diff options
context:
space:
mode:
authorJohn Gilmore <gnu@cygnus>1992-07-05 10:26:53 +0000
committerJohn Gilmore <gnu@cygnus>1992-07-05 10:26:53 +0000
commitec8ceca3f3116ac39836a9d8a73a53c9b891b8bc (patch)
tree56f502db0dbe679abc8392512ae6e0e73be62702 /gdb/tm-sun4sol2.h
parenta8cd562d42ca1c0d6d6d74028853d8418159e509 (diff)
downloadfsf-binutils-gdb-ec8ceca3f3116ac39836a9d8a73a53c9b891b8bc.zip
fsf-binutils-gdb-ec8ceca3f3116ac39836a9d8a73a53c9b891b8bc.tar.gz
fsf-binutils-gdb-ec8ceca3f3116ac39836a9d8a73a53c9b891b8bc.tar.bz2
* buildsym.c (finish_block): Fix thinko `inner block' complaints.
* dbxread.c (process_one_symbol): Parse N_OPT "gcc2_compiled.". * procfs.c (proc_set_exec_trap): Set run-on-last-close flag on child processes, to avoid dead ones "hanging around" after GDB exits. (attach): Always stop the process if it needs it. Set RLC flag when attaching running processes, so it will continue if we detach it, quit, or are killed. (detach): Clear faults and set RLC flag to make process run when we close it. (open_proc_file): New `mode' argument for O_RDONLY or O_RDWR. Callers changed. (info_proc): Open process O_RDONLY, so we can see any process, even those controlled by debuggers. * tm-sun4sol2.h (SUN_FIXED_LBRAC_BUG): They did (in Sol 2).
Diffstat (limited to 'gdb/tm-sun4sol2.h')
-rw-r--r--gdb/tm-sun4sol2.h11
1 files changed, 9 insertions, 2 deletions
diff --git a/gdb/tm-sun4sol2.h b/gdb/tm-sun4sol2.h
index 78c7389..76251d9 100644
--- a/gdb/tm-sun4sol2.h
+++ b/gdb/tm-sun4sol2.h
@@ -30,9 +30,16 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
#define BLOCK_ADDRESS_FUNCTION_RELATIVE
-/* Variables in the debug stabs occur after the N_LBRAC, not before it. */
+/* Variables in the debug stabs occur after the N_LBRAC, not before it,
+ in code generated by Sun C. */
-#define VARIABLES_INSIDE_BLOCK(desc, gcc_p) (!gcc_p)
+#define VARIABLES_INSIDE_BLOCK(desc, gcc_p) (!(gcc_p))
+
+/* There's no need to correct LBRAC entries by guessing how they should
+ work. In fact, this is harmful because the LBRAC entries now all appear
+ at the end of the function, not intermixed with the SLINE entries. */
+
+#define SUN_FIXED_LBRAC_BUG
/* May be needed, may be not? From Pace Willisson's port. FIXME. */
#define PROLOGUE_FIRSTLINE_OVERLAP